@@ -67,7 +67,14 @@ class Hived(HttpClient):
 
         assert chain in known_chains, "The chain you are connecting " + \
                                       "to is not supported"
-        return known_chains.get(chain)
+        #return known_chains.get(chain)
+        # temporarily use chain_id from get_version until after HF24
+        chain = known_chains.get(chain)
+        version = self.get_version()
+        if version['chain_id'] != '0000000000000000000000000000000000000000000000000000000000000000':
+          print('Switching to chain_id '+version['chain_id'])
+          chain['chain_id'] = version['chain_id']
+        return chain
 
     def get_replies(self, author, skip_own=True):
         """ Get replies for an author
@@ -892,7 +899,7 @@ class Hived(HttpClient):
 
     def get_version(self):
         """ Get hived version of the node currently connected to. """
-        return self.call('get_version', api='login_api')
+        return self.call('get_version', api='database_api')
 
     def get_followers(self, account, start_follower,
                       follow_type, limit):
